@@ -546,8 +546,8 @@ test_that("unmarshal list of structures", {
   )
   req <- unmarshal(req)
   out <- req$data
-  expect_equivalent(out$List[[1]], list(Bar = "firstbar", Baz = "firstbaz", Foo = "firstfoo"))
-  expect_equivalent(out$List[[2]], list(Bar = "secondbar", Baz = "secondbaz", Foo = "secondfoo"))
+  expect_equal(out$List[[1]], list(Bar = "firstbar", Baz = "firstbaz", Foo = "firstfoo"), ignore_attr = TRUE)
+  expect_equal(out$List[[2]], list(Bar = "secondbar", Baz = "secondbaz", Foo = "secondfoo"), ignore_attr = TRUE)
 })
 
 op_output7 <- Structure(
@@ -569,8 +569,8 @@ test_that("unmarshal flattened list of structures", {
   )
   req <- unmarshal(req)
   out <- req$data
-  expect_equivalent(out$List[[1]], list(Bar = "firstbar", Baz = "firstbaz", Foo = "firstfoo"))
-  expect_equivalent(out$List[[2]], list(Bar = "secondbar", Baz = "secondbaz", Foo = "secondfoo"))
+  expect_equal(out$List[[1]], list(Bar = "firstbar", Baz = "firstbaz", Foo = "firstfoo"), ignore_attr = TRUE)
+  expect_equal(out$List[[2]], list(Bar = "secondbar", Baz = "secondbaz", Foo = "secondfoo"), ignore_attr = TRUE)
 })
 
 op_output8 <- Structure(
